clear all;
close all;

% Declare variables to fill
s = [1 2 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 20 21 22 23 24 25 26]; %Two files were left out because of errors in data collection
accuracyScores = [];
sensSpecs = [];
predictionIntervals = [];

% Loop of number of iterations
for numIterations = 1:10
%     Separate seizures into two groups and construct the tree
    forTree = datasample(s,12,'Replace',false);
    forPredict = setdiff(s,forTree);
    totalData = combineData(forTree);
    tree = decisionTree(totalData);

%     Iterate over each seizure for testing
    for xx = 1:12
%         Prepare data for prediction
        jj = forPredict(xx);
        if jj<10
            inputECGFileName = strcat('EEG_0',int2str(jj),'.txt');
        else
            inputECGFileName = strcat('EEG_',int2str(jj),'.txt');
        end
        simFile = importdata(fullfile(pwd,inputECGFileName));
        
%         Get labels
        labels = simFile.data(:,2);
        
%         Classify all data for this seizure file
        dataToPredict = simFile.data(:,3:4);
        [predictions score] = predict(tree,dataToPredict);
        
%         Compress data such that three consecutive -1s or 1s are required
%         for an alert
        minConsecutive = 3;
        alerts = getAlerts(labels, predictions, minConsecutive);
        
%         Compute prediction interval and sensitivity for this seizure and
%         append to the array
        predictionIntervals=[predictionIntervals;find(labels==-1,1)-find(alerts==-1,1)];
        sensSpecs = [sensSpecs;getSensSpec(labels,alerts)];
    end
end

% Get statistics for the prediction interval and sensitivity
a = round(std(predictionIntervals(:,1)),1);
b = round(mean(predictionIntervals(:,1)),1);
c = round(std(sensSpecs(:,1)),1);
d = round(mean(sensSpecs(:,1)),1);

% Plot histogram of prediction interval
histogram(predictionIntervals(:,1))
xlabel('Prediction Interval (s)');
ylabel('Number of simulations');
title('Prediction interval of each simulation tested');
PIStr = {['Mean = ' num2str(b) ' seconds'],['Standard Deviation = ' num2str(a) ' seconds']};
text(-20,80,PIStr,'FontSize',12);
set(gca,'FontSize',12)

% Plot histogram of sensitivity
figure()
histogram(sensSpecs(:,1),10)
xlabel('Sensitivity (%)');
ylabel('Number of simulations');
title('Sensitivity of each simulation tested');
sensStr = {['Mean = ' num2str(d) ' %'],['Standard Deviation = ' num2str(c) ' %']};
text(40,80,sensStr,'FontSize',12);
set(gca,'FontSize',12)

